# -*- coding: utf-8 -*-

# mapWOC
#
# Description: Triggering chain of events as if a result.tar.gz was synched.
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2011 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import logging
from multiprocessing import Queue
from optparse import OptionParser
from shutil import copy, rmtree
import tempfile

from mapwoc.masterctrl.resultpollprocess import ResultPollProcess

def prepare_dir(filepath):
    tempdir = tempfile.mkdtemp()
    copy(filepath, tempdir)
    return tempdir

logger = logging.getLogger('master')
logger.setLevel(logging.DEBUG)
logger.addHandler(logging.StreamHandler())

parser = OptionParser()
parser.add_option("-f", "--file", dest="inputfile",
                  help="Path to file that was result of an mapwocanalyse.pl run.")
parser.add_option("-d", "--db", dest="db",
                  help="Path to database file (database will be populated.")
parser.add_option("-t", "--tolerance", dest="tolerance", type="int",
                  help="Tolerance (ignore results with severity < tolerance).")

(options, args) = parser.parse_args()

complaints = []
if options.inputfile is None:
    complaints.append("'file' parameter has to be set.")

if options.db is None:
    complaints.append("'db' parameter has to be set.")

if len(complaints) > 0:
    for c in complaints:
        print c
    exit(1)


# Better than monkey patch.
rpp = ResultPollProcess('/tmp', [], Queue(), '', options.db, options.tolerance)
rpp._ResultPollProcess__bind_to_db()

td = prepare_dir(options.inputfile)

# Cross your finger now.
rpp._ResultPollProcess__resultdir_to_db(td, "Direct Testinput")

# Remove temporary data.
rmtree(td)

exit(0)
